pub struct AnswerOption {
pub answer: String,
pub shorthand: String,
pub tags: Vec<Uuid>,
}Fields
answer: StringThe text shown to the patient as possible answer option
shorthand: StringShort form of the answer shown in the calendar
Tags to automatically add to the reservation, if this answer is selected by the patient
Implementations
Sourceimpl AnswerOption
impl AnswerOption