pub struct ExtraQuestion {
pub text: String,
pub exactly_one: bool,
pub options: Vec<AnswerOption>,
}Fields
text: StringThe question that gets asked to the patient on booking an appointment
exactly_one: boolWhether the patient has to select exactly one answer, or multiple answers are allowed
options: Vec<AnswerOption>The answer options
Implementations
Sourceimpl ExtraQuestion
impl ExtraQuestion
pub fn new( text: String, exactly_one: bool, options: Vec<AnswerOption>, ) -> ExtraQuestion