pub struct ListWrapperAvailabilityDataInner {
pub availability_id: Uuid,
pub tenant_id: Uuid,
pub worker_id: Uuid,
pub day_of_week: DayOfWeek,
pub start_time: String,
pub end_time: String,
pub services: Vec<Uuid>,
pub not_before: Option<Option<String>>,
pub not_after: Option<Option<String>>,
}Expand description
ListWrapperAvailabilityDataInner : Definition of a time slot, that is available regularly for booking
Fields
availability_id: UuidID of this availability
tenant_id: Uuidthe tenant this availability belongs to
worker_id: Uuidthis availability is for this worker
day_of_week: DayOfWeekwhich day of the week this availability is for
start_time: Stringtime of the day this availability starts
end_time: Stringtime of the day this availability ends
services: Vec<Uuid>list of services available for this availability (empty for all services available)
not_before: Option<Option<String>>limit the availability to a certain date range (start date, inclusive)
not_after: Option<Option<String>>limit the availability to a certain date range (end date, inclusive)
Implementations