pub struct ListWrapperServiceDataInner {
pub service_id: Uuid,
pub tenant_id: Uuid,
pub name: String,
pub expenditure_minutes: i32,
pub default_tags: Vec<Uuid>,
pub questions: Vec<ExtraQuestion>,
pub color: Option<Option<String>>,
pub last_change: String,
}Fields
service_id: UuidID of the service
tenant_id: Uuidtenant this service is assocciated with
name: Stringname of the offered service
expenditure_minutes: i32how many minutes have to be reserved for this service
which tags should get added automatically to a reservation generated for this service
questions: Vec<ExtraQuestion>which questions should be asked to the patient if he selects this service
color: Option<Option<String>>which color shall be used to show reservations for this service in the calendar
last_change: Stringwhen has this service be updated for the last time
Implementations